@@ -42,8 +42,13 @@ static GdkModifierType gsd_ignored_mods = 0;
 static GdkModifierType gsd_used_mods = 0;
 
 /* Taken from a comment in XF86keysym.h */
-static guint gsd_unmodified_keysym_min = 0x10080001;
-static guint gsd_unmodified_keysym_max = 0x1008FFFF;
+#define XF86KEYS_RANGE_MIN 0x10080001
+#define XF86KEYS_RANGE_MAX 0x1008FFFF
+
+#define FKEYS_RANGE_MIN GDK_KEY_F1
+#define FKEYS_RANGE_MAX GDK_KEY_F35
+
+#define IN_RANGE(x, min, max) (x >= min && x <= max)
 
 static void
 setup_modifiers (void)
@@ -137,12 +142,13 @@ grab_key_unsafe (Key                 *key,
         /* If key doesn't have a usable modifier, we don't want
          * to grab it, since the user might lose a useful key.
          *
-         * The exception is the XFree86 keys (which are useful to grab without
-         * a modifier).
+         * The exception is the XFree86 keys and the Function keys
+         * (which are useful to grab without a modifier).
          */
         if ((modifiers & gsd_used_mods) == 0 &&
-            ((key->keysym < gsd_unmodified_keysym_min) ||
-             (key->keysym > gsd_unmodified_keysym_max))) {
+            (IN_RANGE(key->keysym, XF86KEYS_RANGE_MIN, XF86KEYS_RANGE_MAX) ||
+             IN_RANGE(key->keysym, FKEYS_RANGE_MIN, FKEYS_RANGE_MAX) ||
+             key->keysym == GDK_KEY_Pause)) {
                 GString *keycodes;
 
                 keycodes = g_string_new ("");
