@@ -32,6 +32,9 @@ typedef enum {
         MUTE_KEY,
         VOLUME_DOWN_KEY,
         VOLUME_UP_KEY,
+        MUTE_QUIET_KEY,
+        VOLUME_DOWN_QUIET_KEY,
+        VOLUME_UP_QUIET_KEY,
         LOGOUT_KEY,
         EJECT_KEY,
         HOME_KEY,
@@ -71,12 +74,15 @@ static struct {
         const char *hard_coded;
         Key *key;
 } keys[HANDLED_KEYS] = {
-        { TOUCHPAD_KEY, "touchpad", NULL, NULL },
+        { TOUCHPAD_KEY, NULL, "XF86TouchpadToggle", NULL },
 	{ TOUCHPAD_ON_KEY, NULL, "XF86TouchpadOn", NULL },
 	{ TOUCHPAD_OFF_KEY, NULL, "XF86TouchpadOff", NULL },
-        { MUTE_KEY, "volume-mute",NULL, NULL },
+        { MUTE_KEY, "volume-mute", NULL, NULL },
         { VOLUME_DOWN_KEY, "volume-down", NULL, NULL },
         { VOLUME_UP_KEY, "volume-up", NULL, NULL },
+        { MUTE_QUIET_KEY, NULL, "<Alt>XF86AudioMute", NULL },
+        { VOLUME_DOWN_QUIET_KEY, NULL, "<Alt>XF86AudioLowerVolume", NULL },
+        { VOLUME_UP_QUIET_KEY, NULL, "<Alt>XF86AudioRaiseVolume", NULL },
         { LOGOUT_KEY, "logout", NULL, NULL },
         { EJECT_KEY, "eject", NULL, NULL },
         { HOME_KEY, "home", NULL, NULL },
