@@ -126,7 +126,7 @@ struct GsdMediaKeysManagerPrivate
 static void     gsd_media_keys_manager_class_init  (GsdMediaKeysManagerClass *klass);
 static void     gsd_media_keys_manager_init        (GsdMediaKeysManager      *media_keys_manager);
 static void     gsd_media_keys_manager_finalize    (GObject                  *object);
-
+static void     register_manager                   (GsdMediaKeysManager      *manager);
 G_DEFINE_TYPE (GsdMediaKeysManager, gsd_media_keys_manager, G_TYPE_OBJECT)
 
 static gpointer manager_object = NULL;
@@ -331,7 +331,7 @@ update_kbd_cb (GSettings           *settings,
                         }
 
                         key = g_new0 (Key, 1);
-                        if (!egg_accelerator_parse_virtual (tmp, &key->keysym, &key->keycodes, &key->state)) {
+                        if (egg_accelerator_parse_virtual (tmp, &key->keysym, &key->keycodes, &key->state) != EGG_PARSE_ERROR_NONE) {
                                 g_free (tmp);
                                 g_free (key);
                                 break;
@@ -366,6 +366,7 @@ init_kbd (GsdMediaKeysManager *manager)
         for (i = 0; i < HANDLED_KEYS; i++) {
                 char *tmp;
                 Key  *key;
+                EggParseError ret;
 
                 if (keys[i].settings_key != NULL) {
                         tmp = g_settings_get_string (manager->priv->settings, keys[i].settings_key);
@@ -374,14 +375,19 @@ init_kbd (GsdMediaKeysManager *manager)
                 }
 
                 if (!is_valid_shortcut (tmp)) {
-                        g_debug ("Not a valid shortcut: '%s'", tmp);
+                        if (*tmp != '\0')
+                                g_debug ("Not a valid shortcut: '%s'", tmp);
                         g_free (tmp);
                         continue;
                 }
 
                 key = g_new0 (Key, 1);
-                if (!egg_accelerator_parse_virtual (tmp, &key->keysym, &key->keycodes, &key->state)) {
-                        g_debug ("Unable to parse: '%s'", tmp);
+                ret = egg_accelerator_parse_virtual (tmp, &key->keysym, &key->keycodes, &key->state);
+                if (ret != EGG_PARSE_ERROR_NONE) {
+                        if (keys[i].settings_key != NULL)
+                                g_debug ("Unable to parse key '%s' for GSettings entry '%s' (%d)", tmp, keys[i].settings_key, ret);
+                        else
+                                g_debug ("Unable to parse hard-coded key '%s' (%d)", keys[i].hard_coded, ret);
                         g_free (tmp);
                         g_free (key);
                         continue;
@@ -412,10 +418,7 @@ dialog_show (GsdMediaKeysManager *manager)
         int            screen_h;
         int            x;
         int            y;
-        int            pointer_x;
-        int            pointer_y;
         GtkRequisition win_req;
-        GdkScreen     *pointer_screen;
         GdkRectangle   geometry;
         int            monitor;
 
@@ -430,29 +433,12 @@ dialog_show (GsdMediaKeysManager *manager)
         gtk_window_get_default_size (GTK_WINDOW (manager->priv->dialog), &orig_w, &orig_h);
         gtk_widget_size_request (manager->priv->dialog, &win_req);
 
-        if (win_req.width > orig_w) {
+        if (win_req.width > orig_w)
                 orig_w = win_req.width;
-        }
-        if (win_req.height > orig_h) {
+        if (win_req.height > orig_h)
                 orig_h = win_req.height;
-        }
 
-        pointer_screen = NULL;
-        gdk_display_get_pointer (gdk_screen_get_display (manager->priv->current_screen),
-                                 &pointer_screen,
-                                 &pointer_x,
-                                 &pointer_y,
-                                 NULL);
-        if (pointer_screen != manager->priv->current_screen) {
-                /* The pointer isn't on the current screen, so just
-                 * assume the default monitor
-                 */
-                monitor = 0;
-        } else {
-                monitor = gdk_screen_get_monitor_at_point (manager->priv->current_screen,
-                                                           pointer_x,
-                                                           pointer_y);
-        }
+        monitor = gdk_screen_get_primary_monitor (manager->priv->current_screen);
 
         gdk_screen_get_monitor_geometry (manager->priv->current_screen,
                                          monitor,
@@ -587,32 +573,6 @@ do_eject_action (GsdMediaKeysManager *manager)
         g_object_unref (volume_monitor);
 }
 
-static void
-do_touchpad_action (GsdMediaKeysManager *manager)
-{
-        GSettings *settings;
-        gboolean state;
-
-        if (touchpad_is_present () == FALSE) {
-                dialog_init (manager);
-                gsd_media_keys_window_set_action_custom (GSD_MEDIA_KEYS_WINDOW (manager->priv->dialog),
-                                                         "touchpad-disabled", FALSE);
-                return;
-        }
-
-        settings = g_settings_new (SETTINGS_TOUCHPAD_DIR);
-        state = g_settings_get_boolean (settings, TOUCHPAD_ENABLED_KEY);
-
-        dialog_init (manager);
-        gsd_media_keys_window_set_action_custom (GSD_MEDIA_KEYS_WINDOW (manager->priv->dialog),
-                                                 (!state) ? "touchpad-enabled" : "touchpad-disabled",
-                                                 FALSE);
-        dialog_show (manager);
-
-        g_settings_set_boolean (settings, TOUCHPAD_ENABLED_KEY, !state);
-        g_object_unref (settings);
-}
-
 static void
 do_touchpad_osd_action (GsdMediaKeysManager *manager, gboolean state)
 {
@@ -623,13 +583,34 @@ do_touchpad_osd_action (GsdMediaKeysManager *manager, gboolean state)
         dialog_show (manager);
 }
 
+static void
+do_touchpad_action (GsdMediaKeysManager *manager)
+{
+        GSettings *settings;
+        gboolean state;
+
+        if (touchpad_is_present () == FALSE) {
+                do_touchpad_osd_action (manager, FALSE);
+                return;
+        }
+
+        settings = g_settings_new (SETTINGS_TOUCHPAD_DIR);
+        state = g_settings_get_boolean (settings, TOUCHPAD_ENABLED_KEY);
+
+        do_touchpad_osd_action (manager, !state);
+
+        g_settings_set_boolean (settings, TOUCHPAD_ENABLED_KEY, !state);
+        g_object_unref (settings);
+}
+
 #ifdef HAVE_PULSE
 static void
 update_dialog (GsdMediaKeysManager *manager,
                guint vol,
                guint max_vol,
                gboolean muted,
-               gboolean sound_changed)
+               gboolean sound_changed,
+               gboolean quiet)
 {
         vol = (int) (100 * (double) vol / (double) max_vol);
         vol = CLAMP (vol, 0, 100);
@@ -642,7 +623,7 @@ update_dialog (GsdMediaKeysManager *manager,
                                           GSD_MEDIA_KEYS_WINDOW_ACTION_VOLUME);
         dialog_show (manager);
 
-        if (sound_changed != FALSE && muted == FALSE)
+        if (quiet == FALSE && sound_changed != FALSE && muted == FALSE)
                 ca_gtk_play_for_widget (manager->priv->dialog, 0,
                                         CA_PROP_EVENT_ID, "audio-volume-change",
                                         CA_PROP_EVENT_DESCRIPTION, "volume changed through key press",
@@ -652,7 +633,8 @@ update_dialog (GsdMediaKeysManager *manager,
 
 static void
 do_sound_action (GsdMediaKeysManager *manager,
-                 int                  type)
+                 int                  type,
+                 gboolean             quiet)
 {
         gboolean old_muted, new_muted;
         guint old_vol, new_vol, max_vol, norm_vol_step;
@@ -701,7 +683,7 @@ do_sound_action (GsdMediaKeysManager *manager,
                 }
         }
 
-        update_dialog (manager, new_vol, max_vol, new_muted, sound_changed);
+        update_dialog (manager, new_vol, max_vol, new_muted, sound_changed, quiet);
 }
 
 static void
@@ -1176,6 +1158,8 @@ do_action (GsdMediaKeysManager *manager,
         char *cmd;
         char *path;
 
+        g_debug ("Launching action for key type '%d'", type);
+
         switch (type) {
         case TOUCHPAD_KEY:
                 do_touchpad_action (manager);
@@ -1190,7 +1174,22 @@ do_action (GsdMediaKeysManager *manager,
         case VOLUME_DOWN_KEY:
         case VOLUME_UP_KEY:
 #ifdef HAVE_PULSE
-                do_sound_action (manager, type);
+                do_sound_action (manager, type, FALSE);
+#endif /* HAVE_PULSE */
+                break;
+        case MUTE_QUIET_KEY:
+#ifdef HAVE_PULSE
+                do_sound_action (manager, MUTE_KEY, TRUE);
+#endif /* HAVE_PULSE */
+                break;
+        case VOLUME_DOWN_QUIET_KEY:
+#ifdef HAVE_PULSE
+                do_sound_action (manager, VOLUME_DOWN_KEY, TRUE);
+#endif /* HAVE_PULSE */
+                break;
+        case VOLUME_UP_QUIET_KEY:
+#ifdef HAVE_PULSE
+                do_sound_action (manager, VOLUME_UP_KEY, TRUE);
 #endif /* HAVE_PULSE */
                 break;
         case LOGOUT_KEY:
@@ -1334,6 +1333,8 @@ acme_filter_events (GdkXEvent           *xevent,
                         switch (keys[i].key_type) {
                         case VOLUME_DOWN_KEY:
                         case VOLUME_UP_KEY:
+                        case VOLUME_DOWN_QUIET_KEY:
+                        case VOLUME_UP_QUIET_KEY:
                                 /* auto-repeatable keys */
                                 if (xev->type != KeyPress) {
                                         return GDK_FILTER_CONTINUE;
@@ -1462,6 +1463,8 @@ gsd_media_keys_manager_start (GsdMediaKeysManager *manager,
 #endif /* HAVE_PULSE */
         manager->priv->start_idle_id = g_idle_add ((GSourceFunc) start_media_keys_idle_cb, manager);
 
+        register_manager (manager_object);
+
         gnome_settings_profile_end (NULL);
 
         return TRUE;
@@ -1703,7 +1706,6 @@ gsd_media_keys_manager_new (void)
                 manager_object = g_object_new (GSD_TYPE_MEDIA_KEYS_MANAGER, NULL);
                 g_object_add_weak_pointer (manager_object,
                                            (gpointer *) &manager_object);
-                register_manager (manager_object);
         }
 
         return GSD_MEDIA_KEYS_MANAGER (manager_object);
